<?php
/**
 * moment Custom Metabox
 *
 * @package Moment
 */
$moment_post_types = array(
    'post',
    'page'
);

add_action('add_meta_boxes', 'moment_add_layout_metabox');
function moment_add_layout_metabox() {
    global $post;
    $frontpage_id = get_option('page_on_front');
    if( $post->ID == $frontpage_id ){
        return;
    }

    global $moment_post_types;
    foreach ( $moment_post_types as $post_type ) {
        add_meta_box(
            'moment_layout_options', // $id
            __( 'Layout options', 'moment' ), // $title
            'moment_layout_options_callback', // $callback
            $post_type, // $page
            'normal', // $context
            'high'// $priority
        );
    }

}

/* moment featured layout */
$moment_single_post_image_align_options = array(
    'full' => array(
        'value' => 'full',
        'label' => __( 'Full', 'moment' )
    ),
    'right' => array(
        'value' => 'right',
        'label' => __( 'Right ', 'moment' ),
    ),
    'left' => array(
        'value'     => 'left',
        'label' => __( 'Left', 'moment' ),
    ),
    'no-image' => array(
        'value'     => 'no-image',
        'label' => __( 'No Image', 'moment' )
    )
);

function moment_layout_options_callback() {

    global $post , $moment_single_post_image_align_options;
    $moment_customizer_saved_values = moment_get_all_options(1);

    /*moment-single-post-image-align*/
    $moment_single_post_image_align = $moment_customizer_saved_values['moment-single-post-image-align'];

    wp_nonce_field( basename( __FILE__ ), 'moment_layout_options_nonce' );
    ?>
    <table class="form-table page-meta-box">
        <!--Image alignment-->
        <tr>
            <td colspan="4"><em class="f13"><?php _e( 'Choose Sidebar Template', 'moment' ); ?></em></td>
        </tr>
        <!--Image alignment-->
        <tr>
            <td colspan="4"><?php _e( 'Featured Image Alignment', 'moment' ); ?></td>
        </tr>
        <tr>
            <td>
                <?php
                $moment_single_post_image_align_meta = get_post_meta( $post->ID, 'moment-single-post-image-align', true );
                if( false != $moment_single_post_image_align_meta ){
                    $moment_single_post_image_align = $moment_single_post_image_align_meta;
                }
                foreach ($moment_single_post_image_align_options as $field) {
                    ?>
                    <input id="<?php echo esc_attr( $field['value'] ); ?>" type="radio" name="moment-single-post-image-align" value="<?php echo esc_attr( $field['value'] ); ?>" <?php checked( $field['value'], $moment_single_post_image_align ); ?>/>
                    <label class="description" for="<?php echo esc_attr( $field['value'] ); ?>">
                        <?php echo esc_html( $field['label'] ); ?>
                    </label>
                <?php } // end foreach
                ?>
                <div class="clear"></div>
            </td>
        </tr>
    </table>

<?php }

/**
 * save the custom metabox data
 * @hooked to save_post hook
 */
function moment_save_sidebar_layout( $post_id ) {
    global $post;
    // Verify the nonce before proceeding.
    if ( !isset( $_POST[ 'moment_layout_options_nonce' ] ) || !wp_verify_nonce( $_POST[ 'moment_layout_options_nonce' ], basename( __FILE__ ) ) ) {
        return;
    }

    // Stop WP from clearing custom fields on autosave
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }

    if ( !current_user_can( 'edit_page', $post_id ) ) {
        return $post_id;
    }

    /*image align*/
    if(isset($_POST['moment-single-post-image-align'])){
        $old = get_post_meta( $post_id, 'moment-single-post-image-align', true);
        $new = sanitize_text_field($_POST['moment-single-post-image-align']);
        if ($new && $new != $old) {
            update_post_meta($post_id, 'moment-single-post-image-align', $new);
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id,'moment-single-post-image-align', $old);
        }
    }
}
add_action('save_post', 'moment_save_sidebar_layout');
